@@ -8,7 +8,8 @@ set.seed( 123 )
 nObs <- 20
 
 # create data set with explanatory variables
-cesData <- data.frame( xx1 = rchisq( nObs, 10 ), xx2 = rchisq( nObs, 10 ) )
+cesData <- data.frame( xx1 = rchisq( nObs, 10 ), xx2 = rchisq( nObs, 10 ),
+   time = c( 0:( nObs - 1 ) ) )
 
 # names of explanatory variables
 xxNames <- c( "xx1", "xx2" )
@@ -24,8 +25,9 @@ rownames( y ) <- c( -(1:20), 0, (20:1) )
 # calculate endogenous variables
 for( i in 1:length( rhos ) ) {
    # coefficients
-   cesCoef <- c( gamma = 1, delta = 0.6, rho = rhos[ i ], nu = 1.1 )
-   y[ i, ] <- cesCalc( xNames = xxNames, data = cesData, coef = cesCoef )
+   cesCoef <- c( gamma = 1, lambda = 0.02, delta = 0.6, rho = rhos[ i ], nu = 1.1 )
+   y[ i, ] <- cesCalc( xNames = xxNames, tName = "time", data = cesData, 
+      coef = cesCoef )
 }
 
 # print matrix of endogenous variables
@@ -36,7 +38,7 @@ cdCoef <- c( a_0 = unname( log( cesCoef[ "gamma" ] ) ),
    a_1 = unname( cesCoef[ "delta" ] * cesCoef[ "nu" ] ),
    a_2 = unname( ( 1 - cesCoef[ "delta" ] ) * cesCoef[ "nu" ] ) )
 yCd <- cobbDouglasCalc( xNames = xxNames, data = cesData, 
-   coef = cdCoef )
+   coef = cdCoef ) * exp( 0.02 * cesData[[ "time" ]] )
 
 # print endogenous variables for different rhos (adjusted with the y at rho=0)
 for( i in 1:nObs ) {
@@ -53,9 +55,9 @@ dimnames( deriv ) <- list( rhos, 1:nObs, names( cesCoef ) )
 # calculate the derivatives
 for( i in 1:length( rhos ) ) {
    # coefficients
-   cesCoef <- c( gamma = 1, delta = 0.6, rho = rhos[ i ], nu = 1.1 )
+   cesCoef <- c( gamma = 1, lambda = 0.02, delta = 0.6, rho = rhos[ i ], nu = 1.1 )
    deriv[ i, , ] <- micEconCES:::cesDerivCoef( par = cesCoef, 
-      xNames = xxNames, data = cesData, vrs = TRUE, 
+      xNames = xxNames, tName = "time", data = cesData, vrs = TRUE, 
       rhoApprox = c( gamma = 5e-6, delta = 5e-6, rho = 1e-3, nu = 5e-6 ) )
 }
 
@@ -70,21 +72,27 @@ dimnames( derivCd ) <- list( 1:nObs, names( cesCoef ) )
 #    ( 1 - cesCoef[ "delta" ] ) * log( cesData[[ xxNames[ 2 ] ]] ) ) )
 derivCd[ , "gamma" ] <- 
    cesData[[ xxNames[ 1 ] ]]^( cesCoef[ "nu" ] * cesCoef[ "delta" ] ) *
-   cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) )
+   cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) ) *
+   exp( cesCoef[ "lambda" ] * cesData[[ "time" ]] )
+derivCd[ , "lambda" ] <- derivCd[ , "gamma" ] * 
+   cesCoef[ "gamma" ] * cesData[[ "time" ]]
 derivCd[ , "delta" ] <- cesCoef[ "gamma" ] * cesCoef[ "nu" ] * 
    ( log( cesData[[ xxNames[ 1 ] ]] ) - log( cesData[[ xxNames[ 2 ] ]] ) ) *
    cesData[[ xxNames[ 1 ] ]]^( cesCoef[ "nu" ] * cesCoef[ "delta" ] ) *
-   cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) )
+   cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) ) *
+   exp( cesCoef[ "lambda" ] * cesData[[ "time" ]] )
 derivCd[ , "nu" ] <- cesCoef[ "gamma" ] * 
    ( cesCoef[ "delta" ] * log( cesData[[ xxNames[ 1 ] ]] ) +
    ( 1 - cesCoef[ "delta" ] ) * log( cesData[[ xxNames[ 2 ] ]] ) ) *
    cesData[[ xxNames[ 1 ] ]]^( cesCoef[ "nu" ] * cesCoef[ "delta" ] ) *
-   cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) )
+   cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) ) *
+   exp( cesCoef[ "lambda" ] * cesData[[ "time" ]] )
 derivCd[ , "rho" ] <- - 0.5 * cesCoef[ "gamma" ] * cesCoef[ "nu" ] *
    cesCoef[ "delta" ] * ( 1 - cesCoef[ "delta" ] ) *
    cesData[[ xxNames[ 1 ] ]]^( cesCoef[ "nu" ] * cesCoef[ "delta" ] ) *
    cesData[[ xxNames[ 2 ] ]]^( cesCoef[ "nu" ] * ( 1 - cesCoef[ "delta" ] ) ) *
-   ( log( cesData[[ xxNames[ 1 ] ]] ) - log( cesData[[ xxNames[ 2 ] ]] ) )^2
+   ( log( cesData[[ xxNames[ 1 ] ]] ) - log( cesData[[ xxNames[ 2 ] ]] ) )^2 *
+   exp( cesCoef[ "lambda" ] * cesData[[ "time" ]] )
 
 
 
